//*****************************************************************************
//*****************************************************************************
//  FILENAME:  CMX_VarFreqDutyPWM.c
//  Version: 1.1, Updated on 2008/6/23 at 14:10:5 
//  
//
//  DESCRIPTION:  This Driver controls the Variable Frequency PWM parameters
//				  and returns the period and percent duty cycle for the
//				  selected channel.
//-----------------------------------------------------------------------------
//      Copyright (c) Cypress MicroSystems 2004-2006. All Rights Reserved.
//*****************************************************************************
//*****************************************************************************

#include "m8c.h"
#include "CMX_VarFreqDutyPWM.h"
#include "cmx.h"

// Channel type header file
#include "cmx_pwmvfreq_chan.h"

//define constant values
#define MIN_FREQ	50
#define MAX_FREQ	200
#define MAX_DUTY	100
//-----------------------------------------------------------------------------
//  FUNCTION NAME: VarFreqDutyPWM_Instantiate(const CMX_VarFreqDutyPWM_ParameterBlock * thisBLK)
//
//  DESCRIPTION: 
//     VarFreqDutyPWM Initialization
//
//-----------------------------------------------------------------------------
//
//  ARGUMENTS: 
//     thisBLK => Pointer to parameter Block for this instance.
//
//  RETURNS: None
//
//  SIDE EFFECTS: 
//
//  THEORY of OPERATION or PROCEDURE: Initialization for VarFreqDutyPWM
//     Initial conditions set based on parameters set in
//     VarFreqDutyPWM Parameter block
//-----------------------------------------------------------------------------
void CMX_VarFreqDutyPWM_Instantiate(const CMX_VarFreqDutyPWM_ParameterBlock * thisBLK)
{
    BYTE bInstance;
    BYTE Polarity;
    BYTE bPeriod;

    bInstance = thisBLK->VarFreqDutyPWM_ChannelID;
    Polarity = thisBLK->VarFreqDutyPWM_Polarity;

    PWMVFreqSetPolarity(bInstance,Polarity);

	bPeriod = PWMVFreqGetInitialPeriod(bInstance);
    
	PWMVFreqSetPeriod(bInstance, 100);
    PWMVFreqSetDutyCycle(bInstance, 0, bPeriod);
    PWMVFreqStart(bInstance);
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME: VarFreqDutyPWM_SetValue(const CMX_VarFreqDutyPWM_ParameterBlock * thisBLK, int iPercentDutyFreq)
//
//  DESCRIPTION: 
//     Sets the current PWM frequency based on the Base Frequency percent value
//	   given as a parameter.
//
//-----------------------------------------------------------------------------
//
//  ARGUMENTS:  
//     thisBLK            => Pointer to parameter Block for this instance.
//     iPercentDutyFreq => Percentage of Base Frequncy to set is the high byte
//				  Percentage of Duty Cycle to set is the low byte
//
//  RETURNS: None
//
//  SIDE EFFECTS: 
//
//  THEORY of OPERATION or PROCEDURE:
//     Controls the output PWM signal frequency by setting the appropriate
//	   period value and duty cycle value according to the Base Frequency
//	   percentage given for the current instance.
//-----------------------------------------------------------------------------

void CMX_VarFreqDutyPWM_SetValue(const CMX_VarFreqDutyPWM_ParameterBlock * thisBLK, int iPercentDutyFreq)
{
    BYTE bInstance;
    BYTE bPeriod;
	unsigned int uiPercentDutyFreq;
	BYTE bVarFreq; 
	BYTE bVarDuty;
	
	bInstance = thisBLK->VarFreqDutyPWM_ChannelID;
	
	uiPercentDutyFreq = iPercentDutyFreq;
								//define the variable frequency
	bVarFreq = (BYTE)(uiPercentDutyFreq >> 8);
								//define the variable duty
	bVarDuty = (BYTE)uiPercentDutyFreq;
								//verify the maximum and minimum frequency range
	if(bVarFreq < MIN_FREQ) 
		bVarFreq = MIN_FREQ;
	if(bVarFreq > MAX_FREQ) 
		bVarFreq = MAX_FREQ;
								//verify the maximum  duty range
	if(bVarDuty > MAX_DUTY) 
		bVarDuty = MAX_DUTY;
								//calculate the period depending on the frequency
	bPeriod = PWMVFreqGetInitialPeriod(bInstance);
	bPeriod = ((int)bPeriod * 100) / (int)bVarFreq;
								//set the period and duty cycle
	PWMVFreqSetPeriod(bInstance, bPeriod);
    PWMVFreqSetDutyCycle(bInstance, bVarDuty, bPeriod);
}
